# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
import sys
import sphinx_rtd_theme

sys.path.insert(0, os.path.abspath("../.."))
# sys.path.insert(0, os.path.abspath('../../planners'))


# -- Project information -----------------------------------------------------

project = "sbp-env"
copyright = "2021, Tin Lai"
author = "Tin Lai"

# The full version, including alpha/beta/rc tags
release = "1.0"


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.autosummary",
    "sphinx.ext.todo",
    "sphinx.ext.viewcode",
    "sphinx.ext.intersphinx",
    # "sphinx.ext.mathjax",
    "sphinxcontrib.katex",
    "sphinx_autodoc_typehints",  # better typehint and simplify fully quantified class
    "sphinx_autodoc_defaultargs",
    "sphinx.ext.githubpages",
    "sphinx_rtd_theme",
    "sphinx-prompt",  # commandline prompt
]
autoclass_content = "both"  # use both class and __init__ docstring for docs.
# autosummary_generate = True  # Turn on sphinx.ext.autosummary
autodoc_typehints = "description"  # signature or description
todo_include_todos = True
# always_document_param_types = True  # sphinx-autodoc-typehints

intersphinx_mapping = {
    "python": ("http://docs.python.org/3", None),
    "numpy": ("http://docs.scipy.org/doc/numpy/", None),
    "scipy": ("http://docs.scipy.org/doc/scipy/reference/", None),
    "matplotlib": ("http://matplotlib.sourceforge.net/", None),
}

# for sphinx_autodoc_defaultargs (https://pypi.org/project/sphinx-autodoc-defaultargs/)
rst_prolog = (
    """
.. |default| raw:: html

    <div class="default-value-section">"""
    + ' <span class="default-value-label">Default:</span>'
)

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "sphinx_rtd_theme"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]
